@@ -41,9 +41,9 @@
 
 int main(int argc, char **argv)
 {
-    KLocalizedString::setApplicationDomain("krdc");
     const QString appName = QStringLiteral("krdc");
     QApplication app(argc, argv);
+    KLocalizedString::setApplicationDomain("krdc");
     QTime startupTimer;
     startupTimer.start();
 
@@ -95,17 +95,11 @@ int main(int argc, char **argv)
                         QStringLiteral("libvncserver-common@lists.sf.net"), QStringLiteral("http://libvncserver.sourceforge.net/"));
     aboutData.addAuthor(i18n("Abner Silva"), i18n("Telepathy Tubes Integration"), QStringLiteral("abner.silva@kdemail.net"));
     aboutData.setOrganizationDomain("kde.org");
-    KAboutData::setApplicationData(aboutData);
 
-    app.setApplicationName(aboutData.componentName());
-    app.setApplicationDisplayName(aboutData.displayName());
-    app.setOrganizationDomain(aboutData.organizationDomain());
-    app.setApplicationVersion(aboutData.version());
+    KAboutData::setApplicationData(aboutData);
     app.setWindowIcon(QIcon::fromTheme(appName));
 
     QCommandLineParser parser;
-    parser.addVersionOption();
-    parser.addHelpOption();
     aboutData.setupCommandLine(&parser);
 
     // command line options
